"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var sendgrid_wrapper_1 = require("./sendgrid.wrapper");
var template_compiler_1 = require("./template/template-compiler");
var EmailHandler = (function () {
    function EmailHandler(config) {
        this._sendGrid = new sendgrid_wrapper_1.SendgridWrapper(config.sendgrid.apiKey);
        this._templateCompiler = new template_compiler_1.TemplateCompiler();
    }
    EmailHandler.prototype.send = function (emailTemplateConfig, emailTemplateInput) {
        var _this = this;
        emailTemplateInput = this.sanitizeEmailTemplateInput(emailTemplateInput);
        return new Promise(function (resolve, reject) {
            _this._sendGrid.send(emailTemplateInput.toEmail, emailTemplateInput.fromEmail, emailTemplateInput.subject, emailTemplateInput.emailType, _this.getHtmlBasedOnType(emailTemplateConfig, emailTemplateInput))
                .then(function (emailLog) {
                resolve(emailLog);
            })
                .catch(function (error) {
                reject(error);
            });
        });
    };
    EmailHandler.prototype.sanitizeEmailTemplateInput = function (etInput) {
        if (etInput.items) {
            for (var _i = 0, _a = etInput.items; _i < _a.length; _i++) {
                var item = _a[_i];
                if (!etInput.showDeadline)
                    item.deadline = null;
                if (!etInput.showPrice)
                    item.price = null;
            }
        }
        return etInput;
    };
    EmailHandler.prototype.getHtmlBasedOnType = function (emailTemplateConfig, emailTemplateInput) {
        return this._templateCompiler.getHtml(emailTemplateConfig, emailTemplateInput);
    };
    return EmailHandler;
}());
exports.EmailHandler = EmailHandler;
